@@ -37,7 +37,7 @@ BEGIN {
 }
 
 # ABSTRACT: Perl bindings to libarchive via FFI
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 ffi_lib do {
   my $file = locate_module_share_lib();
@@ -622,7 +622,7 @@ Archive::Libarchive::FFI - Perl bindings to libarchive via FFI
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -1171,6 +1171,15 @@ read:
  # or
  my $decoded_content = decode('KOI8-R', $raw);
 
+=head1 SUPPORT
+
+If you find bugs, please open an issue on the project GitHub repository:
+
+L<https://github.com/plicease/Archive-Libarchive-FFI/issues?state=open>
+
+If you have a fix, please open a pull request.  You can see the CONTRIBUTING
+file for traps, hints and pitfalls.
+
 =head1 CAVEATS
 
 Archive and entry objects are really pointers to opaque C structures
